perldocSearch.indexData.modules = new Hash ({
  "attributes": "get/set subroutine or variable attributes",
  "autodie": "Replace functions with ones that succeed or die with lexical scope",
  "autouse": "postpone load of modules until a function is used",
  "base": "Establish an ISA relationship with base classes at compile time",
  "bigint": "Transparent BigInteger support for Perl",
  "bignum": "Transparent BigNumber support for Perl",
  "bigrat": "Transparent BigNumber/BigRational support for Perl",
  "blib": "Use MakeMaker's uninstalled version of a package",
  "bytes": "Perl pragma to expose the individual bytes of characters",
  "charnames": "access to Unicode character names and named character sequences; also define character names",
  "constant": "Perl pragma to declare constants",
  "diagnostics": "produce verbose warning diagnostics",
  "encoding": "allows you to write your script in non-ASCII and non-UTF-8",
  "feature": "Perl pragma to enable new features",
  "fields": "compile-time class fields",
  "filetest": "Perl pragma to control the filetest permission operators",
  "if": "use a Perl module if a condition holds (also can no a module)",
  "integer": "Perl pragma to use integer arithmetic instead of floating point",
  "less": "perl pragma to request less of something",
  "lib": "manipulate @INC at compile time",
  "locale": "Perl pragma to use or avoid POSIX locales for built-in operations",
  "mro": "Method Resolution Order",
  "open": "perl pragma to set default PerlIO layers for input and output",
  "ops": "Perl pragma to restrict unsafe operations when compiling",
  "overload": "Package for overloading Perl operations",
  "overloading": "perl pragma to lexically control overloading",
  "parent": "Establish an ISA relationship with base classes at compile time",
  "re": "Perl pragma to alter regular expression behaviour",
  "sigtrap": "Perl pragma to enable simple signal handling",
  "sort": "perl pragma to control sort() behaviour",
  "strict": "Perl pragma to restrict unsafe constructs",
  "subs": "Perl pragma to predeclare sub names",
  "threads": "Perl interpreter-based threads",
  "threads::shared": "Perl extension for sharing data structures between threads",
  "utf8": "Perl pragma to enable/disable UTF-8 (or UTF-EBCDIC) in source code",
  "vars": "Perl pragma to predeclare global variable names",
  "vmsish": "Perl pragma to control VMS-specific language features",
  "warnings": "Perl pragma to control optional warnings",
  "warnings::register": "warnings import function",
  "Pod::Simple": "framework for parsing Pod",
  "Config": "access Perl configuration information",
  "Params::Check": "A generic input parsing/checking mechanism.",
  "ExtUtils::Embed": "Utilities for embedding Perl in C/C++ applications",
  "ExtUtils::MM_MacOS": "once produced Makefiles for MacOS Classic",
  "Text::Tabs": "expand and unexpand tabs like unix expand(1) and unexpand(1)",
  "ExtUtils::MakeMaker": "Create a module Makefile",
  "PerlIO::encoding": "encoding layer",
  "Text::ParseWords": "parse text into an array of tokens or array of arrays",
  "IPC::Open2": "open a process for both reading and writing using open2()",
  "File::stat": "by-name interface to Perl's built-in stat() functions",
  "Pod::Simple::PullParserEndToken": "end-tokens from Pod::Simple::PullParser",
  "Math::Complex": "complex numbers and associated mathematical functions",
  "ExtUtils::MM_VMS": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
  "File::DosGlob": "DOS like globbing and then some",
  "IO::Poll": "Object interface to system poll call",
  "File::Spec::Functions": "portably perform operations on file names",
  "Socket": "networking constants and support functions",
  "Parse::CPAN::Meta": "Parse META.yml and META.json CPAN metadata files",
  "Locale::Maketext::Simple": "Simple interface to Locale::Maketext::Lexicon",
  "Tie::File": "Access the lines of a disk file via a Perl array",
  "Encode::GSM0338": "ESTI GSM 03.38 Encoding",
  "File::GlobMapper": "Extend File Glob to Allow Input and Output Files",
  "Devel::SelfStubber": "generate stubs for a SelfLoading module",
  "File::Spec::Cygwin": "methods for Cygwin file specs",
  "Pod::Simple::HTML": "convert Pod to HTML",
  "Pod::Simple::HTMLBatch": "convert several Pod files to several HTML files",
  "IO::Pipe": "supply object methods for pipes",
  "ExtUtils::Command": "utilities to replace common UNIX commands in Makefiles etc.",
  "List::Util": "A selection of general-utility list subroutines",
  "Pod::Simple::Search": "find POD documents in directory trees",
  "IO::Uncompress::AnyInflate": "Uncompress zlib-based (zip, gzip) file/buffer",
  "TAP::Formatter::Base": "Base class for harness output delegates",
  "File::Spec::VMS": "methods for VMS file specs",
  "Opcode": "Disable named opcodes when compiling perl code",
  "Archive::Tar": "module for manipulations of tar archives",
  "PerlIO::via::QuotedPrint": "PerlIO layer for quoted-printable strings",
  "TAP::Parser::Result::Pragma": "TAP pragma token.",
  "File::Copy": "Copy files or filehandles",
  "Encode::EBCDIC": "EBCDIC Encodings",
  "Net::Netrc": "OO interface to users netrc file",
  "Compress::Raw::Zlib": "Low-Level Interface to zlib compression library",
  "TAP::Parser::YAMLish::Writer": "Write YAMLish data",
  "Pod::Perldoc::GetOptsOO": "Customized option parser for Pod::Perldoc",
  "Thread::Queue": "Thread-safe queues",
  "Encode::Encoder": "Object Oriented Encoder",
  "Fcntl": "load the C Fcntl.h defines",
  "Test::Builder::Tester": "test testsuites that have been built withTest::Builder",
  "TAP::Formatter::Session": "Abstract base class for harness output delegate ",
  "TAP::Parser": "Parse TAP|Test::Harness::TAP output",
  "Hash::Util": "A selection of general-utility hash subroutines",
  "ExtUtils::MakeMaker::FAQ": "Frequently Asked Questions About MakeMaker",
  "Math::BigInt::FastCalc": "Math::BigInt::Calc with some XS for more speed",
  "Errno": "System errno constants",
  "Dumpvalue": "provides screen dump of Perl data.",
  "ExtUtils::testlib": "add blib/* directories to @INC",
  "Tie::RefHash": "use references as hash keys",
  "IO::Uncompress::RawInflate": "Read RFC 1951 files/buffers",
  "ExtUtils::MM_DOS": "DOS specific subclass of ExtUtils::MM_Unix",
  "CPAN::Kwalify": "Interface between CPAN.pm and Kwalify.pm",
  "DBM_Filter::null": "filter for DBM_Filter",
  "ExtUtils::CBuilder": "Compile and link C code for Perl modules",
  "DBM_Filter::compress": "filter for DBM_Filter",
  "IO::Uncompress::Gunzip": "Read RFC 1952 files/buffers",
  "ExtUtils::Constant::XS": "generate C code for XS modules' constants.",
  "Exporter": "Implements default import method for modules",
  "Encode::KR": "Korean Encodings",
  "AutoLoader": "load subroutines only on demand",
  "Pod::Text::Color": "Convert POD data to formatted color ASCII text",
  "Time::tm": "internal object used by Time::gmtime and Time::localtime",
  "Net::NNTP": "NNTP Client class",
  "IO": "load various IO modules",
  "Module::Load": "runtime require of both modules and files",
  "Encode::KR::2022_KR": "internally used by Encode::KR",
  "ExtUtils::Manifest": "utilities to write and check a MANIFEST file",
  "TAP::Parser::Scheduler::Spinner": "A no-op job.",
  "Getopt::Long": "Extended processing of command line options",
  "Digest::base": "Digest base class",
  "PerlIO::via": "Helper class for PerlIO layers implemented in perl",
  "SelfLoader": "load functions only on demand",
  "TAP::Parser::Iterator": "Base class for TAP source iterators",
  "TAP::Parser::Result": "Base class for TAP::Parser output objects",
  "Module::CoreList": "what modules shipped with versions of perl",
  "Encode::CJKConstants": "Internally used by Encode::??::ISO_2022_*",
  "CPAN::FirstTime": "Utility for CPAN::Config file Initialization",
  "File::Spec": "portably perform operations on file names",
  "Pod::Simple::PullParserStartToken": "start-tokens from Pod::Simple::PullParser",
  "Pod::Perldoc::ToRtf": "let Perldoc render Pod as RTF",
  "Test::Builder::Module": "Base class for test modules",
  "File::Compare": "Compare files or filehandles",
  "IO::Compress::Deflate": "Write RFC 1950 files/buffers",
  "User::grent": "by-name interface to Perl's built-in getgr*() functions",
  "Pod::Html": "module to convert pod files to HTML",
  "Pod::Perldoc::ToNroff": "let Perldoc convert Pod to nroff",
  "TAP::Parser::Result::Comment": "Comment result token.",
  "ExtUtils::Packlist": "manage .packlist files",
  "TAP::Formatter::Console::ParallelSession": "Harness output delegate for parallel console output",
  "Thread": "Manipulate threads in Perl (for old code only)",
  "Unicode::Collate": "Unicode Collation Algorithm",
  "IO::Compress::Gzip": "Write RFC 1952 files/buffers",
  "Time::HiRes": "High resolution alarm, sleep, gettimeofday, interval timers",
  "Net::protoent": "by-name interface to Perl's built-in getproto*() functions",
  "IPC::Semaphore": "SysV Semaphore IPC object class",
  "Pod::Simple::PullParserToken": "tokens from Pod::Simple::PullParser",
  "IPC::SysV": "System V IPC constants and system calls",
  "Math::BigInt::CalcEmu": "Emulate low-level math with BigInt code",
  "Encode::JP::JIS7": "internally used by Encode::JP",
  "Sys::Hostname": "Try every conceivable way to get hostname",
  "Pod::PlainText": "Convert POD data to formatted ASCII text",
  "IO::Socket::INET": "Object interface for AF_INET domain sockets",
  "Encode::Byte": "Single Byte Encodings",
  "DynaLoader": "Dynamically load C libraries into Perl code",
  "Tie::Scalar": "base class definitions for tied scalars",
  "Math::Trig": "trigonometric functions",
  "TAP::Object": "Base class that provides common functionality to all TAP::* modules",
  "Tie::Array": "base class for tied arrays",
  "I18N::Langinfo": "query locale information",
  "ExtUtils::CBuilder::Platform::Windows": "Builder class for Windows platforms",
  "Test::Harness": "Run Perl standard test scripts with statistics",
  "ExtUtils::MM_Win95": "method to customize MakeMaker for Win9X",
  "Attribute::Handlers": "Simpler definition of attribute handlers",
  "Memoize::NDBM_File": "glue to provide EXISTS for NDBM_File for Storable use",
  "Net::servent": "by-name interface to Perl's built-in getserv*() functions",
  "Encode::Guess": "Guesses encoding from data",
  "Class::Struct": "declare struct-like datatypes as Perl classes",
  "Pod::Perldoc::ToChecker": "let Perldoc check Pod for errors",
  "Test::Builder": "Backend for building test libraries",
  "DBM_Filter::int32": "filter for DBM_Filter",
  "ExtUtils::MM_NW5": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
  "Getopt::Std": "Process single-character switches with switch clustering",
  "ExtUtils::MM_Win32": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
  "CPAN::Debug": "internal debugging for CPAN.pm",
  "File::Fetch": "A generic file fetching mechanism",
  "Term::ReadLine": "Perl interface to various readline packages.If no real package is found, substitutes stubs instead of basic functions.",
  "ExtUtils::Constant::Utils": "helper functions for ExtUtils::Constant",
  "Scalar::Util": "A selection of general-utility scalar subroutines",
  "Locale::Language": "standard codes for language identification",
  "FindBin": "Locate directory of original perl script",
  "Benchmark": "benchmark running times of Perl code",
  "Net::hostent": "by-name interface to Perl's built-in gethost*() functions",
  "ExtUtils::MY": "ExtUtils::MakeMaker subclass for customization",
  "FileCache": "keep more files open than the system permits",
  "Pod::Select": "extract selected sections of POD from input",
  "Locale::Maketext::GutsLoader": "Deprecated module to load Locale::Maketext utf8 code",
  "TAP::Parser::Result::Plan": "Plan result token.",
  "Encode::JP": "Japanese Encodings",
  "Pod::Checker": "check pod documents for syntax errors",
  "Pod::Text::Termcap": "Convert POD data to ASCII text with format escapes",
  "Locale::Maketext::Guts": "Deprecated module to load Locale::Maketext utf8 code",
  "ExtUtils::Mkbootstrap": "make a bootstrap file for use by DynaLoader",
  "Pod::Usage": "print a usage message from embedded pod documentation",
  "Pod::Text": "Convert POD data to formatted text",
  "Pod::ParseUtils": "helpers for POD parsing and conversion",
  "Pod::Perldoc::ToPod": "let Perldoc render Pod as ... Pod!",
  "CPAN::Version": "utility functions to compare CPAN versions",
  "I18N::LangTags": "functions for dealing with RFC3066-style language tags",
  "Safe": "Compile and execute code in restricted compartments",
  "IO::File": "supply object methods for filehandles",
  "ExtUtils::ParseXS": "converts Perl XS code into C code",
  "Encode::MIME::Header": "MIME encoding for an unstructured email header",
  "File::Find": "Traverse a directory tree.",
  "DBM_Filter::encode": "filter for DBM_Filter",
  "Test": "provides a simple framework for writing test scripts",
  "Hash::Util::FieldHash": "Support for Inside-Out Classes",
  "Exporter::Heavy": "Exporter guts",
  "App::Prove::State::Result": "Individual test suite results.",
  "Time::localtime": "by-name interface to Perl's built-in localtime() function",
  "Module::Load::Conditional": "Looking up module information / loading at runtime",
  "Pod::Functions": "Group Perl's functions a la perlfunc.pod",
  "File::Spec::Epoc": "methods for Epoc file specs",
  "Devel::PPPort": "Perl/Pollution/Portability",
  "ExtUtils::Command::MM": "Commands for the MM's to use in Makefiles",
  "IO::Socket": "Object interface to socket communications",
  "File::Temp": "return name and handle of a temporary file safely",
  "Locale::Script": "standard codes for script identification",
  "TAP::Parser::Result::Test": "Test result token.",
  "Digest::MD5": "Perl interface to the MD5 Algorithm",
  "Text::Balanced": "Extract delimited text sequences from strings.",
  "Net::Domain": "Attempt to evaluate the current host's internet name and domain",
  "TAP::Formatter::Color": "Run Perl test scripts with color",
  "TAP::Formatter::File": "Harness output delegate for file output",
  "Pod::Perldoc::ToTk": "let Perldoc use Tk::Pod to render Pod",
  "Memoize::Storable": "store Memoized data in Storable database",
  "Unicode::UCD": "Unicode character database",
  "Encode::TW": "Taiwan-based Chinese Encodings",
  "Pod::Perldoc": "Look up Perl documentation in Pod format.",
  "AutoSplit": "split a package for autoloading",
  "TAP::Parser::Result::Version": "TAP syntax version token.",
  "Locale::Country": "standard codes for country identification",
  "File::Path": "Create or remove directory trees",
  "ExtUtils::Mksymlists": "write linker options files for dynamic extension",
  "CPAN::HandleConfig": "internal configuration handling for CPAN.pm",
  "Memoize::Expire": "Plug-in module for automatic expiration of memoized values",
  "TAP::Parser::Result::Unknown": "Unknown result token.",
  "SDBM_File": "Tied access to sdbm files",
  "Pod::Simple::Methody": "turn Pod::Simple events into method calls",
  "IO::Compress::RawDeflate": "Write RFC 1951 files/buffers",
  "ExtUtils::MM_Any": "Platform-agnostic MM methods",
  "IO::Uncompress::AnyUncompress": "Uncompress gzip, zip, bzip2 or lzop file/buffer",
  "TAP::Formatter::Console": "Harness output delegate for default console output",
  "B::Deparse": "Perl compiler backend to produce perl code",
  "FileHandle": "supply object methods for filehandles",
  "File::Glob": "Perl extension for BSD glob routine",
  "Digest::file": "Calculate digests of files",
  "Encode::Symbol": "Symbol Encodings",
  "B::Debug": "Walk Perl syntax tree, printing debug info about ops",
  "I18N::LangTags::List": "tags and names for human languages",
  "List::Util::XS": "Indicate if List::Util was compiled with a C compiler",
  "ExtUtils::Constant": "generate XS code to import C header constants",
  "App::Prove::State::Result::Test": "Individual test results.",
  "IO::Socket::UNIX": "Object interface for AF_UNIX domain sockets",
  "Test::Builder::Tester::Color": "turn on colour in Test::Builder::Tester",
  "TAP::Parser::Source": "a TAP source & meta data about it",
  "ExtUtils::MM_UWIN": "U/WIN specific subclass of ExtUtils::MM_Unix",
  "ExtUtils::MM_QNX": "QNX specific subclass of ExtUtils::MM_Unix",
  "Pod::Simple::Checker": "check the Pod syntax of a document",
  "Term::ANSIColor": "Color screen output using ANSI escape sequences",
  "TAP::Parser::Multiplexer": "Multiplex multiple TAP::Parsers",
  "MIME::QuotedPrint": "Encoding and decoding of quoted-printable strings",
  "Time::Seconds": "a simple API to convert seconds to other date values",
  "B": "The Perl Compiler Backend",
  "TAP::Base": "Base class that provides common functionality to TAP::Parserand TAP::Harness",
  "Test::More": "yet another framework for writing test scripts",
  "B::Concise": "Walk Perl syntax tree, printing concise info about ops",
  "PerlIO": "On demand loader for PerlIO layers and root of PerlIO::* name space",
  "ExtUtils::MM_BeOS": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
  "TAP::Parser::Iterator::Process": "Iterator for process-based TAP sources",
  "IO::Dir": "supply object methods for directory handles",
  "IO::Uncompress::Inflate": "Read RFC 1950 files/buffers",
  "UNIVERSAL": "base class for ALL classes (blessed references)",
  "Test::Simple": "Basic utilities for writing tests.",
  "ExtUtils::MM_Cygwin": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
  "Fatal": "Replace functions with equivalents which succeed or die",
  "IPC::Msg": "SysV Msg IPC object class",
  "B::Terse": "Walk Perl syntax tree, printing terse info about ops",
  "CPAN": "query, download and build perl modules from CPAN sites",
  "Net::netent": "by-name interface to Perl's built-in getnet*() functions",
  "Encode": "character encodings in Perl",
  "IO::Zlib": "IO:: style interface to Compress::Zlib",
  "Memoize::SDBM_File": "glue to provide EXISTS for SDBM_File for Storable use",
  "Net::FTP": "FTP Client class",
  "Pod::Man": "Convert POD data to formatted *roff input",
  "Net::POP3": "Post Office Protocol 3 Client class (RFC1939)",
  "B::Xref": "Generates cross reference reports for Perl programs",
  "ExtUtils::MM_VOS": "VOS specific subclass of ExtUtils::MM_Unix",
  "Math::BigRat": "Arbitrary big rational numbers",
  "TAP::Formatter::File::Session": "Harness output delegate for file output",
  "IO::Uncompress::Unzip": "Read zip files/buffers",
  "Encode::Encoding": "Encode Implementation Base Class",
  "IO::Uncompress::Bunzip2": "Read bzip2 files/buffers",
  "Sys::Syslog": "Perl interface to the UNIX syslog(3) calls",
  "Unicode::Normalize": "Unicode Normalization Forms",
  "Filter::Util::Call": "Perl Source Filter Utility Module",
  "ExtUtils::MM_OS2": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
  "Text::Wrap": "line wrapping to form simple paragraphs",
  "Text::Abbrev": "abbrev - create an abbreviation table from a list",
  "Pod::Parser": "base class for creating POD filters and translators",
  "SelectSaver": "save and restore selected file handle",
  "Time::gmtime": "by-name interface to Perl's built-in gmtime() function",
  "IPC::SharedMem": "SysV Shared Memory IPC object class",
  "App::Prove::State": "State storage for the prove command.",
  "Time::Local": "Efficiently compute time from local and GMT time",
  "DBM_Filter::utf8": "filter for DBM_Filter",
  "Pod::Simple::RTF": "format Pod as RTF",
  "Pod::ParseLink": "Parse an L&lt;&gt; formatting code in POD text",
  "Tie::Handle": "base class definitions for tied handles",
  "Pod::Simple::PullParser": "a pull-parser interface to parsing Pod",
  "Memoize::ExpireFile": "test for Memoize expiration semantics",
  "IO::Select": "OO interface to the select system call",
  "Locale::Maketext": "framework for localization",
  "I18N::Collate": "compare 8-bit scalar data according to the current locale",
  "Pod::Simple::Text": "format Pod as plaintext",
  "TAP::Parser::Scheduler::Job": "A single testing job.",
  "ExtUtils::MakeMaker::Tutorial": "Writing a module with MakeMaker",
  "IO::Uncompress::Base": "Base Class for IO::Uncompress modules ",
  "ExtUtils::Installed": "Inventory management of installed modules",
  "Encode::CN::HZ": "internally used by Encode::CN",
  "Pod::Perldoc::ToXml": "let Perldoc render Pod as XML",
  "TAP::Parser::IteratorFactory": "Figures out which SourceHandler objects to use for a given Source",
  "TAP::Harness": "Run test scripts with statistics",
  "Net::Config": "Local configuration data for libnet",
  "ExtUtils::Miniperl": "write the C code for miniperlmain.c and perlmain.c",
  "Archive::Tar::File": "a subclass for in-memory extracted file from Archive::Tar",
  "TAP::Parser::Iterator::Stream": "Iterator for filehandle-based TAP sources",
  "Pod::Simple::LinkSection": "represent \"section\" attributes of L codes",
  "IO::Compress::Zip": "Write zip files/buffers",
  "Encode::Alias": "alias definitions to encodings",
  "Memoize::AnyDBM_File": "glue to provide EXISTS for AnyDBM_File for Storable use",
  "Pod::Text::Overstrike": "=for stopwordsoverstrike",
  "Pod::Perldoc::BaseTo": "Base for Pod::Perldoc formatters",
  "Pod::Escapes": "for resolving Pod E&lt;...&gt; sequences",
  "Storable": "persistence for Perl data structures",
  "TAP::Parser::Scheduler": "Schedule tests during parallel testing",
  "Symbol": "manipulate Perl symbols and their names",
  "Term::Cap": "Perl termcap interface",
  "Math::BigInt": "Arbitrary size integer/float math package",
  "IO::Compress::Base": "Base Class for IO::Compress modules ",
  "TAP::Parser::Result::Bailout": "Bailout result token.",
  "Pod::Find": "find POD documents in directory trees",
  "Net::FTP::dataconn": "FTP Client data connection class",
  "English": "use nice English (or awk) names for ugly punctuation variables",
  "Pod::InputObjects": "objects representing POD input paragraphs, commands, etc.",
  "Tie::Hash": "base class definitions for tied hashes",
  "TAP::Parser::Result::YAML": "YAML result token.",
  "Math::BigInt::Calc": "Pure Perl module to support Math::BigInt",
  "TAP::Parser::Grammar": "A grammar for the Test Anything Protocol.",
  "File::Spec::Mac": "File::Spec for Mac OS (Classic)",
  "Filter::Simple": "Simplified source filtering",
  "XSLoader": "Dynamically load C libraries into Perl code",
  "IO::Handle": "supply object methods for I/O handles",
  "TAP::Formatter::Console::Session": "Harness output delegate for default console output",
  "Carp": "alternative warn and die for modules",
  "Search::Dict": "look - search for key in dictionary file",
  "ExtUtils::Liblist": "determine libraries to use and how to use them",
  "CPAN::Queue": "internal queue support for CPAN.pm",
  "ExtUtils::Constant::Base": "base class for ExtUtils::Constant objects",
  "IO::Seekable": "supply seek based methods for I/O objects",
  "Tie::Memoize": "add data to hash when needed",
  "B::Showlex": "Show lexical variables used in functions or files",
  "Time::Piece": "Object Oriented time objects",
  "Pod::Simple::DumpAsXML": "turn Pod into XML",
  "DB": "programmatic interface to the Perl debugging API",
  "Data::Dumper": "stringified perl data structures, suitable for both printing and eval",
  "IPC::Cmd": "finding and running system commands made easy",
  "Env": "perl module that imports environment variables as scalars or arrays",
  "Encode::CN": "China-based Chinese Encodings",
  "I18N::LangTags::Detect": "detect the user's language preferences",
  "Config::Extensions": "hash lookup of which core extensions were built.",
  "Pod::Perldoc::ToText": "let Perldoc render Pod as plaintext",
  "Encode::Unicode": "Various Unicode Transformation Formats",
  "Pod::Simple::XMLOutStream": "turn Pod into XML",
  "CPAN::Distroprefs": "read and match distroprefs",
  "Pod::Simple::XHTML": "format Pod as validating XHTML",
  "Net::Cmd": "Network Command class (as used by FTP, SMTP etc)",
  "Encode::Config": "internally used by Encode",
  "Pod::Simple::DumpAsText": "dump Pod-parsing events as text",
  "Encode::JP::H2Z": "internally used by Encode::JP::2022_JP*",
  "Digest": "Modules that calculate message digests",
  "Math::BigFloat": "Arbitrary size floating point math package",
  "Net::Time": "time and daytime network client interface",
  "Module::Loaded": "mark modules as loaded or unloaded",
  "ExtUtils::MM_AIX": "AIX specific subclass of ExtUtils::MM_Unix",
  "Cwd": "get pathname of current working directory",
  "TAP::Parser::ResultFactory": "Factory for creating TAP::Parser output objects",
  "File::Spec::Win32": "methods for Win32 file specs",
  "Memoize::ExpireTest": "test for Memoize expiration semantics",
  "ExtUtils::Install": "install files from here to there",
  "IPC::Open3": "open a process for reading, writing, and error handling using open3()",
  "ExtUtils::MM_Darwin": "special behaviors for OS X",
  "Net::Ping": "check a remote host for reachability",
  "Pod::Perldoc::ToMan": "let Perldoc render Pod as man pages",
  "Compress::Raw::Bzip2": "Low-Level Interface to bzip2 compression library",
  "PerlIO::scalar": "in-memory IO, scalar IO",
  "App::Prove": "Implements the prove command.",
  "Thread::Semaphore": "Thread-safe semaphores",
  "Compress::Zlib": "Interface to zlib compression library",
  "Tie::SubstrHash": "Fixed-table-size, fixed-key-length hashing",
  "NEXT": "Provide a pseudo-class NEXT (et al) that allows method redispatch",
  "Tie::StdHandle": "base class definitions for tied handles",
  "NDBM_File": "Tied access to ndbm files",
  "CPAN::Tarzip": "internal handling of tar archives for CPAN.pm",
  "TAP::Parser::Aggregator": "Aggregate TAP::Parser results",
  "Net::SMTP": "Simple Mail Transfer Protocol Client",
  "Pod::Simple::SimpleTree": "parse Pod into a simple parse tree ",
  "MIME::Base64": "Encoding and decoding of base64 strings",
  "Encode::Unicode::UTF7": "UTF-7 encoding",
  "Pod::Simple::TextContent": "get the text content of Pod",
  "File::Basename": "Parse file paths into directory, filename and suffix.",
  "Devel::Peek": "A data debugging tool for the XS programmer",
  "File::Spec::Unix": "File::Spec for Unix, base for other File::Spec modules",
  "TAP::Parser::YAMLish::Reader": "Read YAMLish data from iterator",
  "ExtUtils::MM": "OS adjusted ExtUtils::MakeMaker subclass",
  "Digest::SHA": "Perl extension for SHA-1/224/256/384/512",
  "Locale::Currency": "standard codes for currency identification",
  "DirHandle": "supply object methods for directory handles",
  "Encode::MIME::Name": "internally used by Encode",
  "ExtUtils::MakeMaker::Config": "Wrapper around Config.pm",
  "CPAN::Nox": "Wrapper around CPAN.pm without using any XS module",
  "ExtUtils::MM_Unix": "methods used by ExtUtils::MakeMaker",
  "DB_File": "Perl5 access to Berkeley DB version 1.x",
  "File::Spec::OS2": "methods for OS/2 file specs",
  "Pod::Simple::Debug": "put Pod::Simple into trace/debug mode",
  "IO::Compress::Bzip2": "Write bzip2 files/buffers",
  "Pod::Simple::PullParserTextToken": "text-tokens from Pod::Simple::PullParser",
  "Memoize": "Make functions faster by trading space for time",
  "Term::Complete": "Perl word completion module",
  "POSIX": "Perl interface to IEEE Std 1003.1",
  "User::pwent": "by-name interface to Perl's built-in getpw*() functions",
  "Tie::Hash::NamedCapture": "Named regexp capture buffers",
  "DBM_Filter": "Filter DBM keys/values ",
  "O": "Generic interface to Perl Compiler backends",
  "AnyDBM_File": "provide framework for multiple DBMs",
  "TAP::Parser::Iterator::Array": "Iterator for array-based TAP sources"
});
